pyLBM.boundary.anti_bounce_back
===============================

.. currentmodule:: pyLBM.boundary

.. autoclass:: anti_bounce_back

   

   .. HACK -- the point here is that we don't want this to appear in the output, but the autosummary should still generate the pages.
      .. autosummary::
         :toctree:
      
         anti_bounce_back.prepare_rhs
         anti_bounce_back.set_iload
         anti_bounce_back.set_rhs
         anti_bounce_back.update



   

